# Librería crer PDFs

[Por Carlos Soto De Dios](https://www.linkedin.com/in/carlos-soto-537655224/)

<br>

Librería que te permite crear un Pdf con el nombre que quieres, y con el contenido que desees.

Para utilizarlo simplemente necesitas incluir por parametros de la funcion lo siguiente

```
crear(nombre_archivo, contenido)
```

Siendo nombre_archivo en " " como se llamara el documento .pdf creado y como segundo parametro el contenido de este pdf.

<br>

## 💡 Prerequisitos

[Python 3](https://www.python.org/downloads/release/python-370/)

<br>

## 📚 Ejemplo de uso

```
from Crea_pdf import crear

crear('Documento', "Estoy dentro del PDF")
```
